"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .formfieldoption import FormFieldOption, FormFieldOptionTypedDict
from apideck_unify.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class FormFieldType(str, Enum):
    TEXT = "text"
    CHECKBOX = "checkbox"
    TEL = "tel"
    EMAIL = "email"
    URL = "url"
    TEXTAREA = "textarea"
    SELECT = "select"
    FILTERED_SELECT = "filtered-select"
    MULTI_SELECT = "multi-select"
    DATETIME = "datetime"
    DATE = "date"
    TIME = "time"
    NUMBER = "number"


class FormFieldTypedDict(TypedDict):
    id: NotRequired[str]
    r"""The unique identifier of the form field."""
    label: NotRequired[str]
    r"""The label of the field"""
    placeholder: NotRequired[Nullable[str]]
    r"""The placeholder for the form field"""
    description: NotRequired[Nullable[str]]
    r"""The description of the form field"""
    type: NotRequired[FormFieldType]
    required: NotRequired[bool]
    r"""Indicates if the form field is required, which means it must be filled in before the form can be submitted"""
    custom_field: NotRequired[bool]
    allow_custom_values: NotRequired[bool]
    r"""Only applicable to select fields. Allow the user to add a custom value though the option select if the desired value is not in the option select list."""
    disabled: NotRequired[Nullable[bool]]
    r"""Indicates if the form field is displayed in a “read-only” mode."""
    hidden: NotRequired[Nullable[bool]]
    r"""Indicates if the form field is not displayed but the value that is being stored on the connection."""
    deprecated: NotRequired[Nullable[bool]]
    r"""When the setting is deprecated, it should be hidden from the user interface. The value will still be stored on the connection for the sake of backwards compatibility."""
    sensitive: NotRequired[Nullable[bool]]
    r"""Indicates if the form field contains sensitive data, which will display the value as a masked input."""
    prefix: NotRequired[Nullable[str]]
    r"""Prefix to display in front of the form field."""
    suffix: NotRequired[Nullable[str]]
    r"""Suffix to display next to the form field."""
    options: NotRequired[List[FormFieldOptionTypedDict]]


class FormField(BaseModel):
    id: Optional[str] = None
    r"""The unique identifier of the form field."""

    label: Optional[str] = None
    r"""The label of the field"""

    placeholder: OptionalNullable[str] = UNSET
    r"""The placeholder for the form field"""

    description: OptionalNullable[str] = UNSET
    r"""The description of the form field"""

    type: Optional[FormFieldType] = None

    required: Optional[bool] = None
    r"""Indicates if the form field is required, which means it must be filled in before the form can be submitted"""

    custom_field: Optional[bool] = None

    allow_custom_values: Optional[bool] = False
    r"""Only applicable to select fields. Allow the user to add a custom value though the option select if the desired value is not in the option select list."""

    disabled: OptionalNullable[bool] = UNSET
    r"""Indicates if the form field is displayed in a “read-only” mode."""

    hidden: OptionalNullable[bool] = UNSET
    r"""Indicates if the form field is not displayed but the value that is being stored on the connection."""

    deprecated: OptionalNullable[bool] = UNSET
    r"""When the setting is deprecated, it should be hidden from the user interface. The value will still be stored on the connection for the sake of backwards compatibility."""

    sensitive: OptionalNullable[bool] = UNSET
    r"""Indicates if the form field contains sensitive data, which will display the value as a masked input."""

    prefix: OptionalNullable[str] = UNSET
    r"""Prefix to display in front of the form field."""

    suffix: OptionalNullable[str] = UNSET
    r"""Suffix to display next to the form field."""

    options: Optional[List[FormFieldOption]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "id",
            "label",
            "placeholder",
            "description",
            "type",
            "required",
            "custom_field",
            "allow_custom_values",
            "disabled",
            "hidden",
            "deprecated",
            "sensitive",
            "prefix",
            "suffix",
            "options",
        ]
        nullable_fields = [
            "placeholder",
            "description",
            "disabled",
            "hidden",
            "deprecated",
            "sensitive",
            "prefix",
            "suffix",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from apideck_unify import models, utils
from apideck_unify._hooks import HookContext
from apideck_unify.types import OptionalNullable, UNSET
from apideck_unify.utils import get_security_from_env
from typing import Any, Dict, Mapping, Optional, Union


class AgedDebtorsSDK(BaseSDK):
    def get(
        self,
        *,
        raw: Optional[bool] = False,
        service_id: Optional[str] = None,
        filter_: Optional[
            Union[models.AgedReportFilter, models.AgedReportFilterTypedDict]
        ] = None,
        pass_through: Optional[Dict[str, Any]] = None,
        fields: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AccountingAgedDebtorsOneResponse:
        r"""Get Aged Debtors

        Get Aged Debtors

        :param raw: Include raw response. Mostly used for debugging purposes
        :param service_id: Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.
        :param filter_: Apply filters
        :param pass_through: Optional unmapped key/values that will be passed through to downstream as query parameters. Ie: ?pass_through[search]=leads becomes ?search=leads
        :param fields: The 'fields' parameter allows API users to specify the fields they want to include in the API response. If this parameter is not present, the API will return all available fields. If this parameter is present, only the fields specified in the comma-separated string will be included in the response. Nested properties can also be requested by using a dot notation. <br /><br />Example: `fields=name,email,addresses.city`<br /><br />In the example above, the response will only include the fields \"name\", \"email\" and \"addresses.city\". If any other fields are available, they will be excluded.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.AccountingAgedDebtorsOneRequest(
            raw=raw,
            service_id=service_id,
            filter_=utils.get_pydantic_model(
                filter_, Optional[models.AgedReportFilter]
            ),
            pass_through=pass_through,
            fields=fields,
        )

        req = self._build_request(
            method="GET",
            path="/accounting/aged-debtors",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            _globals=models.AccountingAgedDebtorsOneGlobals(
                consumer_id=self.sdk_configuration.globals.consumer_id,
                app_id=self.sdk_configuration.globals.app_id,
            ),
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="accounting.agedDebtorsOne",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "402", "404", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.AccountingAgedDebtorsOneResponse(
                get_aged_debtors_response=utils.unmarshal_json(
                    http_res.text, Optional[models.GetAgedDebtorsResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.BadRequestResponseData)
            raise models.BadRequestResponse(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnauthorizedResponseData)
            raise models.UnauthorizedResponse(data=data)
        if utils.match_response(http_res, "402", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, models.PaymentRequiredResponseData
            )
            raise models.PaymentRequiredResponse(data=data)
        if utils.match_response(http_res, "404", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.NotFoundResponseData)
            raise models.NotFoundResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnprocessableResponseData)
            raise models.UnprocessableResponse(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return models.AccountingAgedDebtorsOneResponse(
                unexpected_error_response=utils.unmarshal_json(
                    http_res.text, Optional[models.UnexpectedErrorResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_async(
        self,
        *,
        raw: Optional[bool] = False,
        service_id: Optional[str] = None,
        filter_: Optional[
            Union[models.AgedReportFilter, models.AgedReportFilterTypedDict]
        ] = None,
        pass_through: Optional[Dict[str, Any]] = None,
        fields: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AccountingAgedDebtorsOneResponse:
        r"""Get Aged Debtors

        Get Aged Debtors

        :param raw: Include raw response. Mostly used for debugging purposes
        :param service_id: Provide the service id you want to call (e.g., pipedrive). Only needed when a consumer has activated multiple integrations for a Unified API.
        :param filter_: Apply filters
        :param pass_through: Optional unmapped key/values that will be passed through to downstream as query parameters. Ie: ?pass_through[search]=leads becomes ?search=leads
        :param fields: The 'fields' parameter allows API users to specify the fields they want to include in the API response. If this parameter is not present, the API will return all available fields. If this parameter is present, only the fields specified in the comma-separated string will be included in the response. Nested properties can also be requested by using a dot notation. <br /><br />Example: `fields=name,email,addresses.city`<br /><br />In the example above, the response will only include the fields \"name\", \"email\" and \"addresses.city\". If any other fields are available, they will be excluded.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.AccountingAgedDebtorsOneRequest(
            raw=raw,
            service_id=service_id,
            filter_=utils.get_pydantic_model(
                filter_, Optional[models.AgedReportFilter]
            ),
            pass_through=pass_through,
            fields=fields,
        )

        req = self._build_request_async(
            method="GET",
            path="/accounting/aged-debtors",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            _globals=models.AccountingAgedDebtorsOneGlobals(
                consumer_id=self.sdk_configuration.globals.consumer_id,
                app_id=self.sdk_configuration.globals.app_id,
            ),
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="accounting.agedDebtorsOne",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "402", "404", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.AccountingAgedDebtorsOneResponse(
                get_aged_debtors_response=utils.unmarshal_json(
                    http_res.text, Optional[models.GetAgedDebtorsResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.BadRequestResponseData)
            raise models.BadRequestResponse(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnauthorizedResponseData)
            raise models.UnauthorizedResponse(data=data)
        if utils.match_response(http_res, "402", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, models.PaymentRequiredResponseData
            )
            raise models.PaymentRequiredResponse(data=data)
        if utils.match_response(http_res, "404", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.NotFoundResponseData)
            raise models.NotFoundResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnprocessableResponseData)
            raise models.UnprocessableResponse(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return models.AccountingAgedDebtorsOneResponse(
                unexpected_error_response=utils.unmarshal_json(
                    http_res.text, Optional[models.UnexpectedErrorResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from apideck_unify.types import BaseModel
from typing_extensions import TypedDict


class CreateSessionResponseDataTypedDict(TypedDict):
    session_uri: str
    session_token: str


class CreateSessionResponseData(BaseModel):
    session_uri: str

    session_token: str


class CreateSessionResponseTypedDict(TypedDict):
    r"""Session created"""

    status_code: int
    r"""HTTP Response Status Code"""
    status: str
    r"""HTTP Response Status"""
    data: CreateSessionResponseDataTypedDict


class CreateSessionResponse(BaseModel):
    r"""Session created"""

    status_code: int
    r"""HTTP Response Status Code"""

    status: str
    r"""HTTP Response Status"""

    data: CreateSessionResponseData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from apideck_unify.ageddebtors_sdk import AgedDebtorsSDK
from apideck_unify.attachments import Attachments
from apideck_unify.balancesheet_sdk import BalanceSheetSDK
from apideck_unify.billpayments import BillPayments
from apideck_unify.bills import Bills
from apideck_unify.companyinfo_sdk import CompanyInfoSDK
from apideck_unify.creditnotes import CreditNotes
from apideck_unify.customers import Customers
from apideck_unify.departments import Departments
from apideck_unify.expenses import Expenses
from apideck_unify.invoiceitems import InvoiceItems
from apideck_unify.invoices import Invoices
from apideck_unify.journalentries import JournalEntries
from apideck_unify.ledgeraccounts import LedgerAccounts
from apideck_unify.locations import Locations
from apideck_unify.payments import Payments
from apideck_unify.profitandloss_sdk import ProfitAndLossSDK
from apideck_unify.purchaseorders import PurchaseOrders
from apideck_unify.subsidiaries import Subsidiaries
from apideck_unify.suppliers import Suppliers
from apideck_unify.taxrates import TaxRates
from apideck_unify.trackingcategories import TrackingCategories


class Accounting(BaseSDK):
    tax_rates: TaxRates
    bills: Bills
    invoices: Invoices
    ledger_accounts: LedgerAccounts
    invoice_items: InvoiceItems
    credit_notes: CreditNotes
    customers: Customers
    suppliers: Suppliers
    payments: Payments
    company_info: CompanyInfoSDK
    balance_sheet: BalanceSheetSDK
    profit_and_loss: ProfitAndLossSDK
    journal_entries: JournalEntries
    purchase_orders: PurchaseOrders
    subsidiaries: Subsidiaries
    locations: Locations
    departments: Departments
    attachments: Attachments
    tracking_categories: TrackingCategories
    bill_payments: BillPayments
    expenses: Expenses
    aged_debtors: AgedDebtorsSDK

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.tax_rates = TaxRates(self.sdk_configuration)
        self.bills = Bills(self.sdk_configuration)
        self.invoices = Invoices(self.sdk_configuration)
        self.ledger_accounts = LedgerAccounts(self.sdk_configuration)
        self.invoice_items = InvoiceItems(self.sdk_configuration)
        self.credit_notes = CreditNotes(self.sdk_configuration)
        self.customers = Customers(self.sdk_configuration)
        self.suppliers = Suppliers(self.sdk_configuration)
        self.payments = Payments(self.sdk_configuration)
        self.company_info = CompanyInfoSDK(self.sdk_configuration)
        self.balance_sheet = BalanceSheetSDK(self.sdk_configuration)
        self.profit_and_loss = ProfitAndLossSDK(self.sdk_configuration)
        self.journal_entries = JournalEntries(self.sdk_configuration)
        self.purchase_orders = PurchaseOrders(self.sdk_configuration)
        self.subsidiaries = Subsidiaries(self.sdk_configuration)
        self.locations = Locations(self.sdk_configuration)
        self.departments = Departments(self.sdk_configuration)
        self.attachments = Attachments(self.sdk_configuration)
        self.tracking_categories = TrackingCategories(self.sdk_configuration)
        self.bill_payments = BillPayments(self.sdk_configuration)
        self.expenses = Expenses(self.sdk_configuration)
        self.aged_debtors = AgedDebtorsSDK(self.sdk_configuration)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from apideck_unify import models, utils
from apideck_unify._hooks import HookContext
from apideck_unify.types import OptionalNullable, UNSET
from apideck_unify.utils import get_security_from_env
from typing import Any, Dict, List, Mapping, Optional, Union


class ConnectionSettings(BaseSDK):
    def list(
        self,
        *,
        unified_api: str,
        service_id: str,
        resource: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VaultConnectionSettingsAllResponse:
        r"""Get resource settings

        This endpoint returns custom settings and their defaults required by connection for a given resource.


        :param unified_api: Unified API
        :param service_id: Service ID of the resource to return
        :param resource: Name of the resource (plural)
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.VaultConnectionSettingsAllRequest(
            unified_api=unified_api,
            service_id=service_id,
            resource=resource,
        )

        req = self._build_request(
            method="GET",
            path="/vault/connections/{unified_api}/{service_id}/{resource}/config",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            _globals=models.VaultConnectionSettingsAllGlobals(
                consumer_id=self.sdk_configuration.globals.consumer_id,
                app_id=self.sdk_configuration.globals.app_id,
            ),
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="vault.connectionSettingsAll",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "402", "404", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.VaultConnectionSettingsAllResponse(
                get_connection_response=utils.unmarshal_json(
                    http_res.text, Optional[models.GetConnectionResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.BadRequestResponseData)
            raise models.BadRequestResponse(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnauthorizedResponseData)
            raise models.UnauthorizedResponse(data=data)
        if utils.match_response(http_res, "402", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, models.PaymentRequiredResponseData
            )
            raise models.PaymentRequiredResponse(data=data)
        if utils.match_response(http_res, "404", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.NotFoundResponseData)
            raise models.NotFoundResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnprocessableResponseData)
            raise models.UnprocessableResponse(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return models.VaultConnectionSettingsAllResponse(
                unexpected_error_response=utils.unmarshal_json(
                    http_res.text, Optional[models.UnexpectedErrorResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_async(
        self,
        *,
        unified_api: str,
        service_id: str,
        resource: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VaultConnectionSettingsAllResponse:
        r"""Get resource settings

        This endpoint returns custom settings and their defaults required by connection for a given resource.


        :param unified_api: Unified API
        :param service_id: Service ID of the resource to return
        :param resource: Name of the resource (plural)
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.VaultConnectionSettingsAllRequest(
            unified_api=unified_api,
            service_id=service_id,
            resource=resource,
        )

        req = self._build_request_async(
            method="GET",
            path="/vault/connections/{unified_api}/{service_id}/{resource}/config",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            _globals=models.VaultConnectionSettingsAllGlobals(
                consumer_id=self.sdk_configuration.globals.consumer_id,
                app_id=self.sdk_configuration.globals.app_id,
            ),
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="vault.connectionSettingsAll",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "402", "404", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.VaultConnectionSettingsAllResponse(
                get_connection_response=utils.unmarshal_json(
                    http_res.text, Optional[models.GetConnectionResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.BadRequestResponseData)
            raise models.BadRequestResponse(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnauthorizedResponseData)
            raise models.UnauthorizedResponse(data=data)
        if utils.match_response(http_res, "402", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, models.PaymentRequiredResponseData
            )
            raise models.PaymentRequiredResponse(data=data)
        if utils.match_response(http_res, "404", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.NotFoundResponseData)
            raise models.NotFoundResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnprocessableResponseData)
            raise models.UnprocessableResponse(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return models.VaultConnectionSettingsAllResponse(
                unexpected_error_response=utils.unmarshal_json(
                    http_res.text, Optional[models.UnexpectedErrorResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def update(
        self,
        *,
        service_id: str,
        unified_api: str,
        resource: str,
        enabled: Optional[bool] = None,
        settings: OptionalNullable[Dict[str, Any]] = UNSET,
        metadata: OptionalNullable[Dict[str, Any]] = UNSET,
        configuration: Optional[
            Union[
                List[models.ConnectionConfiguration],
                List[models.ConnectionConfigurationTypedDict],
            ]
        ] = None,
        custom_mappings: Optional[
            Union[
                List[models.CustomMappingInput],
                List[models.CustomMappingInputTypedDict],
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VaultConnectionSettingsUpdateResponse:
        r"""Update settings

        Update default values for a connection's resource settings

        :param service_id: Service ID of the resource to return
        :param unified_api: Unified API
        :param resource: Name of the resource (plural)
        :param enabled: Whether the connection is enabled or not. You can enable or disable a connection using the Update Connection API.
        :param settings: Connection settings. Values will persist to `form_fields` with corresponding id
        :param metadata: Attach your own consumer specific metadata
        :param configuration:
        :param custom_mappings: List of custom mappings configured for this connection
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.VaultConnectionSettingsUpdateRequest(
            service_id=service_id,
            unified_api=unified_api,
            resource=resource,
            connection=models.ConnectionInput(
                enabled=enabled,
                settings=settings,
                metadata=metadata,
                configuration=utils.get_pydantic_model(
                    configuration, Optional[List[models.ConnectionConfiguration]]
                ),
                custom_mappings=utils.get_pydantic_model(
                    custom_mappings, Optional[List[models.CustomMappingInput]]
                ),
            ),
        )

        req = self._build_request(
            method="PATCH",
            path="/vault/connections/{unified_api}/{service_id}/{resource}/config",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            _globals=models.VaultConnectionSettingsUpdateGlobals(
                consumer_id=self.sdk_configuration.globals.consumer_id,
                app_id=self.sdk_configuration.globals.app_id,
            ),
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.connection, False, False, "json", models.ConnectionInput
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="vault.connectionSettingsUpdate",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "402", "404", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.VaultConnectionSettingsUpdateResponse(
                update_connection_response=utils.unmarshal_json(
                    http_res.text, Optional[models.UpdateConnectionResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.BadRequestResponseData)
            raise models.BadRequestResponse(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnauthorizedResponseData)
            raise models.UnauthorizedResponse(data=data)
        if utils.match_response(http_res, "402", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, models.PaymentRequiredResponseData
            )
            raise models.PaymentRequiredResponse(data=data)
        if utils.match_response(http_res, "404", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.NotFoundResponseData)
            raise models.NotFoundResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnprocessableResponseData)
            raise models.UnprocessableResponse(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return models.VaultConnectionSettingsUpdateResponse(
                unexpected_error_response=utils.unmarshal_json(
                    http_res.text, Optional[models.UnexpectedErrorResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def update_async(
        self,
        *,
        service_id: str,
        unified_api: str,
        resource: str,
        enabled: Optional[bool] = None,
        settings: OptionalNullable[Dict[str, Any]] = UNSET,
        metadata: OptionalNullable[Dict[str, Any]] = UNSET,
        configuration: Optional[
            Union[
                List[models.ConnectionConfiguration],
                List[models.ConnectionConfigurationTypedDict],
            ]
        ] = None,
        custom_mappings: Optional[
            Union[
                List[models.CustomMappingInput],
                List[models.CustomMappingInputTypedDict],
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VaultConnectionSettingsUpdateResponse:
        r"""Update settings

        Update default values for a connection's resource settings

        :param service_id: Service ID of the resource to return
        :param unified_api: Unified API
        :param resource: Name of the resource (plural)
        :param enabled: Whether the connection is enabled or not. You can enable or disable a connection using the Update Connection API.
        :param settings: Connection settings. Values will persist to `form_fields` with corresponding id
        :param metadata: Attach your own consumer specific metadata
        :param configuration:
        :param custom_mappings: List of custom mappings configured for this connection
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.VaultConnectionSettingsUpdateRequest(
            service_id=service_id,
            unified_api=unified_api,
            resource=resource,
            connection=models.ConnectionInput(
                enabled=enabled,
                settings=settings,
                metadata=metadata,
                configuration=utils.get_pydantic_model(
                    configuration, Optional[List[models.ConnectionConfiguration]]
                ),
                custom_mappings=utils.get_pydantic_model(
                    custom_mappings, Optional[List[models.CustomMappingInput]]
                ),
            ),
        )

        req = self._build_request_async(
            method="PATCH",
            path="/vault/connections/{unified_api}/{service_id}/{resource}/config",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            _globals=models.VaultConnectionSettingsUpdateGlobals(
                consumer_id=self.sdk_configuration.globals.consumer_id,
                app_id=self.sdk_configuration.globals.app_id,
            ),
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.connection, False, False, "json", models.ConnectionInput
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="vault.connectionSettingsUpdate",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "402", "404", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.VaultConnectionSettingsUpdateResponse(
                update_connection_response=utils.unmarshal_json(
                    http_res.text, Optional[models.UpdateConnectionResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )
        if utils.match_response(http_res, "400", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.BadRequestResponseData)
            raise models.BadRequestResponse(data=data)
        if utils.match_response(http_res, "401", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnauthorizedResponseData)
            raise models.UnauthorizedResponse(data=data)
        if utils.match_response(http_res, "402", "application/json"):
            data = utils.unmarshal_json(
                http_res.text, models.PaymentRequiredResponseData
            )
            raise models.PaymentRequiredResponse(data=data)
        if utils.match_response(http_res, "404", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.NotFoundResponseData)
            raise models.NotFoundResponse(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.UnprocessableResponseData)
            raise models.UnprocessableResponse(data=data)
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "default", "application/json"):
            return models.VaultConnectionSettingsUpdateResponse(
                unexpected_error_response=utils.unmarshal_json(
                    http_res.text, Optional[models.UnexpectedErrorResponse]
                ),
                http_meta=models.HTTPMetadata(request=req, response=http_res),
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .passthroughbody import PassThroughBody, PassThroughBodyTypedDict
from .sharedlinktarget import SharedLinkTarget, SharedLinkTargetTypedDict
from apideck_unify.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from datetime import datetime
from enum import Enum
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class Scope(str, Enum):
    r"""The scope of the shared link."""

    PUBLIC = "public"
    COMPANY = "company"


class SharedLinkTypedDict(TypedDict):
    url: NotRequired[Nullable[str]]
    r"""The URL that can be used to view the file."""
    download_url: NotRequired[Nullable[str]]
    r"""The URL that can be used to download the file."""
    target: NotRequired[SharedLinkTargetTypedDict]
    scope: NotRequired[Nullable[Scope]]
    r"""The scope of the shared link."""
    password_protected: NotRequired[Nullable[bool]]
    r"""Indicated if the shared link is password protected."""
    expires_at: NotRequired[Nullable[datetime]]
    updated_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was last updated."""
    created_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was created."""
    pass_through: NotRequired[List[PassThroughBodyTypedDict]]
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""


class SharedLink(BaseModel):
    url: OptionalNullable[str] = UNSET
    r"""The URL that can be used to view the file."""

    download_url: OptionalNullable[str] = UNSET
    r"""The URL that can be used to download the file."""

    target: Optional[SharedLinkTarget] = None

    scope: OptionalNullable[Scope] = UNSET
    r"""The scope of the shared link."""

    password_protected: OptionalNullable[bool] = UNSET
    r"""Indicated if the shared link is password protected."""

    expires_at: OptionalNullable[datetime] = UNSET

    updated_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was last updated."""

    created_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was created."""

    pass_through: Optional[List[PassThroughBody]] = None
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "url",
            "download_url",
            "target",
            "scope",
            "password_protected",
            "expires_at",
            "updated_at",
            "created_at",
            "pass_through",
        ]
        nullable_fields = [
            "url",
            "download_url",
            "scope",
            "password_protected",
            "expires_at",
            "updated_at",
            "created_at",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class SharedLinkInputTypedDict(TypedDict):
    target_id: Nullable[str]
    r"""The ID of the file or folder to link."""
    download_url: NotRequired[Nullable[str]]
    r"""The URL that can be used to download the file."""
    scope: NotRequired[Nullable[Scope]]
    r"""The scope of the shared link."""
    password: NotRequired[Nullable[str]]
    r"""Optional password for the shared link."""
    pass_through: NotRequired[List[PassThroughBodyTypedDict]]
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""


class SharedLinkInput(BaseModel):
    target_id: Nullable[str]
    r"""The ID of the file or folder to link."""

    download_url: OptionalNullable[str] = UNSET
    r"""The URL that can be used to download the file."""

    scope: OptionalNullable[Scope] = UNSET
    r"""The scope of the shared link."""

    password: OptionalNullable[str] = UNSET
    r"""Optional password for the shared link."""

    pass_through: Optional[List[PassThroughBody]] = None
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["download_url", "scope", "password", "pass_through"]
        nullable_fields = ["target_id", "download_url", "scope", "password"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .consumermetadata import ConsumerMetadata, ConsumerMetadataTypedDict
from apideck_unify.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UpdateConsumerRequestTypedDict(TypedDict):
    metadata: NotRequired[ConsumerMetadataTypedDict]
    r"""The metadata of the consumer. This is used to display the consumer in the sidebar. This is optional, but recommended."""


class UpdateConsumerRequest(BaseModel):
    metadata: Optional[ConsumerMetadata] = None
    r"""The metadata of the consumer. This is used to display the consumer in the sidebar. This is optional, but recommended."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from apideck_unify.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OddWeeksTypedDict(TypedDict):
    hours_monday: NotRequired[float]
    hours_tuesday: NotRequired[float]
    hours_wednesday: NotRequired[float]
    hours_thursday: NotRequired[float]
    hours_friday: NotRequired[float]
    hours_saturday: NotRequired[float]
    hours_sunday: NotRequired[float]


class OddWeeks(BaseModel):
    hours_monday: Optional[float] = None

    hours_tuesday: Optional[float] = None

    hours_wednesday: Optional[float] = None

    hours_thursday: Optional[float] = None

    hours_friday: Optional[float] = None

    hours_saturday: Optional[float] = None

    hours_sunday: Optional[float] = None


class EvenWeeksTypedDict(TypedDict):
    hours_monday: NotRequired[float]
    hours_tuesday: NotRequired[float]
    hours_wednesday: NotRequired[float]
    hours_thursday: NotRequired[float]
    hours_friday: NotRequired[float]
    hours_saturday: NotRequired[float]
    hours_sunday: NotRequired[float]


class EvenWeeks(BaseModel):
    hours_monday: Optional[float] = None

    hours_tuesday: Optional[float] = None

    hours_wednesday: Optional[float] = None

    hours_thursday: Optional[float] = None

    hours_friday: Optional[float] = None

    hours_saturday: Optional[float] = None

    hours_sunday: Optional[float] = None


class WorkPatternTypedDict(TypedDict):
    odd_weeks: NotRequired[OddWeeksTypedDict]
    even_weeks: NotRequired[EvenWeeksTypedDict]


class WorkPattern(BaseModel):
    odd_weeks: Optional[OddWeeks] = None

    even_weeks: Optional[EvenWeeks] = None


class ScheduleTypedDict(TypedDict):
    id: str
    r"""A unique identifier for an object."""
    start_date: str
    r"""The start date, inclusive, of the schedule period."""
    end_date: str
    r"""The end date, inclusive, of the schedule period."""
    work_pattern: WorkPatternTypedDict


class Schedule(BaseModel):
    id: str
    r"""A unique identifier for an object."""

    start_date: str
    r"""The start date, inclusive, of the schedule period."""

    end_date: str
    r"""The end date, inclusive, of the schedule period."""

    work_pattern: WorkPattern



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .formfieldoptiongroup import FormFieldOptionGroup, FormFieldOptionGroupTypedDict
from .simpleformfieldoption import SimpleFormFieldOption, SimpleFormFieldOptionTypedDict
from typing import Union
from typing_extensions import TypeAliasType


FormFieldOptionTypedDict = TypeAliasType(
    "FormFieldOptionTypedDict",
    Union[SimpleFormFieldOptionTypedDict, FormFieldOptionGroupTypedDict],
)


FormFieldOption = TypeAliasType(
    "FormFieldOption", Union[SimpleFormFieldOption, FormFieldOptionGroup]
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .currency import Currency
from .passthroughbody import PassThroughBody, PassThroughBodyTypedDict
from apideck_unify.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from datetime import datetime
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class StagesTypedDict(TypedDict):
    id: NotRequired[Nullable[str]]
    r"""The unique identifier of the Pipeline Stage."""
    name: NotRequired[Nullable[str]]
    r"""The name of the Pipeline Stage."""
    value: NotRequired[Nullable[str]]
    r"""The value of the Pipeline Stage."""
    win_probability: NotRequired[Nullable[int]]
    r"""The expected probability of winning an Opportunity in this Pipeline Stage. Valid values are [0-100]."""
    display_order: NotRequired[Nullable[int]]
    r"""The order in which the Pipeline Stage is displayed in the UI."""


class Stages(BaseModel):
    id: OptionalNullable[str] = UNSET
    r"""The unique identifier of the Pipeline Stage."""

    name: OptionalNullable[str] = UNSET
    r"""The name of the Pipeline Stage."""

    value: OptionalNullable[str] = UNSET
    r"""The value of the Pipeline Stage."""

    win_probability: OptionalNullable[int] = UNSET
    r"""The expected probability of winning an Opportunity in this Pipeline Stage. Valid values are [0-100]."""

    display_order: OptionalNullable[int] = UNSET
    r"""The order in which the Pipeline Stage is displayed in the UI."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["id", "name", "value", "win_probability", "display_order"]
        nullable_fields = ["id", "name", "value", "win_probability", "display_order"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PipelineTypedDict(TypedDict):
    name: str
    r"""The name of the Pipeline."""
    id: NotRequired[str]
    r"""The unique identifier of the Pipeline."""
    currency: NotRequired[Nullable[Currency]]
    r"""Indicates the associated currency for an amount of money. Values correspond to [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217)."""
    archived: NotRequired[bool]
    r"""Whether the Pipeline is archived or not."""
    active: NotRequired[bool]
    r"""Whether the Pipeline is active or not."""
    display_order: NotRequired[Nullable[int]]
    r"""The order in which the Pipeline is displayed in the UI."""
    win_probability_enabled: NotRequired[bool]
    r"""Whether the Pipeline has win probability enabled or not."""
    stages: NotRequired[List[StagesTypedDict]]
    r"""The Pipeline Stages."""
    updated_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was last updated."""
    created_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was created."""
    pass_through: NotRequired[List[PassThroughBodyTypedDict]]
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""


class Pipeline(BaseModel):
    name: str
    r"""The name of the Pipeline."""

    id: Optional[str] = None
    r"""The unique identifier of the Pipeline."""

    currency: OptionalNullable[Currency] = UNSET
    r"""Indicates the associated currency for an amount of money. Values correspond to [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217)."""

    archived: Optional[bool] = None
    r"""Whether the Pipeline is archived or not."""

    active: Optional[bool] = None
    r"""Whether the Pipeline is active or not."""

    display_order: OptionalNullable[int] = UNSET
    r"""The order in which the Pipeline is displayed in the UI."""

    win_probability_enabled: Optional[bool] = None
    r"""Whether the Pipeline has win probability enabled or not."""

    stages: Optional[List[Stages]] = None
    r"""The Pipeline Stages."""

    updated_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was last updated."""

    created_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was created."""

    pass_through: Optional[List[PassThroughBody]] = None
    r"""The pass_through property allows passing service-specific, custom data or structured modifications in request body when creating or updating resources."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "id",
            "currency",
            "archived",
            "active",
            "display_order",
            "win_probability_enabled",
            "stages",
            "updated_at",
            "created_at",
            "pass_through",
        ]
        nullable_fields = ["currency", "display_order", "updated_at", "created_at"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class WebhookEventType(str, Enum):
    WILDCARD_ = "*"
    CRM_ACTIVITY_CREATED = "crm.activity.created"
    CRM_ACTIVITY_UPDATED = "crm.activity.updated"
    CRM_ACTIVITY_DELETED = "crm.activity.deleted"
    CRM_COMPANY_CREATED = "crm.company.created"
    CRM_COMPANY_UPDATED = "crm.company.updated"
    CRM_COMPANY_DELETED = "crm.company.deleted"
    CRM_CONTACT_CREATED = "crm.contact.created"
    CRM_CONTACT_UPDATED = "crm.contact.updated"
    CRM_CONTACT_DELETED = "crm.contact.deleted"
    CRM_LEAD_CREATED = "crm.lead.created"
    CRM_LEAD_UPDATED = "crm.lead.updated"
    CRM_LEAD_DELETED = "crm.lead.deleted"
    CRM_NOTE_CREATED = "crm.note.created"
    CRM_NOTES_UPDATED = "crm.notes.updated"
    CRM_NOTES_DELETED = "crm.notes.deleted"
    CRM_OPPORTUNITY_CREATED = "crm.opportunity.created"
    CRM_OPPORTUNITY_UPDATED = "crm.opportunity.updated"
    CRM_OPPORTUNITY_DELETED = "crm.opportunity.deleted"
    LEAD_LEAD_CREATED = "lead.lead.created"
    LEAD_LEAD_UPDATED = "lead.lead.updated"
    LEAD_LEAD_DELETED = "lead.lead.deleted"
    VAULT_CONNECTION_CREATED = "vault.connection.created"
    VAULT_CONNECTION_UPDATED = "vault.connection.updated"
    VAULT_CONNECTION_DISABLED = "vault.connection.disabled"
    VAULT_CONNECTION_DELETED = "vault.connection.deleted"
    VAULT_CONNECTION_CALLABLE = "vault.connection.callable"
    VAULT_CONNECTION_REVOKED = "vault.connection.revoked"
    VAULT_CONNECTION_TOKEN_REFRESH_FAILED = "vault.connection.token_refresh.failed"
    ATS_JOB_CREATED = "ats.job.created"
    ATS_JOB_UPDATED = "ats.job.updated"
    ATS_JOB_DELETED = "ats.job.deleted"
    ATS_APPLICANT_CREATED = "ats.applicant.created"
    ATS_APPLICANT_UPDATED = "ats.applicant.updated"
    ATS_APPLICANT_DELETED = "ats.applicant.deleted"
    ACCOUNTING_CUSTOMER_CREATED = "accounting.customer.created"
    ACCOUNTING_CUSTOMER_UPDATED = "accounting.customer.updated"
    ACCOUNTING_CUSTOMER_DELETED = "accounting.customer.deleted"
    ACCOUNTING_INVOICE_CREATED = "accounting.invoice.created"
    ACCOUNTING_INVOICE_UPDATED = "accounting.invoice.updated"
    ACCOUNTING_INVOICE_DELETED = "accounting.invoice.deleted"
    ACCOUNTING_INVOICE_ITEM_CREATED = "accounting.invoice_item.created"
    ACCOUNTING_INVOICE_ITEM_UPDATED = "accounting.invoice_item.updated"
    ACCOUNTING_INVOICE_ITEM_DELETED = "accounting.invoice_item.deleted"
    ACCOUNTING_LEDGER_ACCOUNT_CREATED = "accounting.ledger_account.created"
    ACCOUNTING_LEDGER_ACCOUNT_UPDATED = "accounting.ledger_account.updated"
    ACCOUNTING_LEDGER_ACCOUNT_DELETED = "accounting.ledger_account.deleted"
    ACCOUNTING_TAX_RATE_CREATED = "accounting.tax_rate.created"
    ACCOUNTING_TAX_RATE_UPDATED = "accounting.tax_rate.updated"
    ACCOUNTING_TAX_RATE_DELETED = "accounting.tax_rate.deleted"
    ACCOUNTING_BILL_CREATED = "accounting.bill.created"
    ACCOUNTING_BILL_UPDATED = "accounting.bill.updated"
    ACCOUNTING_BILL_DELETED = "accounting.bill.deleted"
    ACCOUNTING_PAYMENT_CREATED = "accounting.payment.created"
    ACCOUNTING_PAYMENT_UPDATED = "accounting.payment.updated"
    ACCOUNTING_PAYMENT_DELETED = "accounting.payment.deleted"
    ACCOUNTING_SUPPLIER_CREATED = "accounting.supplier.created"
    ACCOUNTING_SUPPLIER_UPDATED = "accounting.supplier.updated"
    ACCOUNTING_SUPPLIER_DELETED = "accounting.supplier.deleted"
    ACCOUNTING_PURCHASE_ORDER_CREATED = "accounting.purchase_order.created"
    ACCOUNTING_PURCHASE_ORDER_UPDATED = "accounting.purchase_order.updated"
    ACCOUNTING_PURCHASE_ORDER_DELETED = "accounting.purchase_order.deleted"
    POS_ORDER_CREATED = "pos.order.created"
    POS_ORDER_UPDATED = "pos.order.updated"
    POS_ORDER_DELETED = "pos.order.deleted"
    POS_PRODUCT_CREATED = "pos.product.created"
    POS_PRODUCT_UPDATED = "pos.product.updated"
    POS_PRODUCT_DELETED = "pos.product.deleted"
    POS_PAYMENT_CREATED = "pos.payment.created"
    POS_PAYMENT_UPDATED = "pos.payment.updated"
    POS_PAYMENT_DELETED = "pos.payment.deleted"
    POS_MERCHANT_CREATED = "pos.merchant.created"
    POS_MERCHANT_UPDATED = "pos.merchant.updated"
    POS_MERCHANT_DELETED = "pos.merchant.deleted"
    POS_LOCATION_CREATED = "pos.location.created"
    POS_LOCATION_UPDATED = "pos.location.updated"
    POS_LOCATION_DELETED = "pos.location.deleted"
    POS_ITEM_CREATED = "pos.item.created"
    POS_ITEM_UPDATED = "pos.item.updated"
    POS_ITEM_DELETED = "pos.item.deleted"
    POS_MODIFIER_CREATED = "pos.modifier.created"
    POS_MODIFIER_UPDATED = "pos.modifier.updated"
    POS_MODIFIER_DELETED = "pos.modifier.deleted"
    POS_MODIFIER_GROUP_CREATED = "pos.modifier-group.created"
    POS_MODIFIER_GROUP_UPDATED = "pos.modifier-group.updated"
    POS_MODIFIER_GROUP_DELETED = "pos.modifier-group.deleted"
    HRIS_EMPLOYEE_CREATED = "hris.employee.created"
    HRIS_EMPLOYEE_UPDATED = "hris.employee.updated"
    HRIS_EMPLOYEE_DELETED = "hris.employee.deleted"
    HRIS_EMPLOYEE_TERMINATED = "hris.employee.terminated"
    HRIS_COMPANY_CREATED = "hris.company.created"
    HRIS_COMPANY_UPDATED = "hris.company.updated"
    HRIS_COMPANY_DELETED = "hris.company.deleted"
    FILE_STORAGE_FILE_CREATED = "file-storage.file.created"
    FILE_STORAGE_FILE_UPDATED = "file-storage.file.updated"
    FILE_STORAGE_FILE_DELETED = "file-storage.file.deleted"
    ISSUE_TRACKING_TICKET_CREATED = "issue-tracking.ticket.created"
    ISSUE_TRACKING_TICKET_UPDATED = "issue-tracking.ticket.updated"
    ISSUE_TRACKING_TICKET_DELETED = "issue-tracking.ticket.deleted"
    ATS_APPLICATION_CREATED = "ats.application.created"
    ATS_APPLICATION_UPDATED = "ats.application.updated"
    ATS_APPLICATION_DELETED = "ats.application.deleted"
    ACCOUNTING_EXPENSE_CREATED = "accounting.expense.created"
    ACCOUNTING_EXPENSE_UPDATED = "accounting.expense.updated"
    ACCOUNTING_EXPENSE_DELETED = "accounting.expense.deleted"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .address import Address, AddressTypedDict
from .currency import Currency
from .customfield import CustomField, CustomFieldTypedDict
from .custommappings import CustomMappings, CustomMappingsTypedDict
from .department import Department, DepartmentTypedDict
from .jobstatus import JobStatus
from apideck_unify.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from datetime import date, datetime
from enum import Enum
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class Visibility(str, Enum):
    r"""The visibility of the job"""

    DRAFT = "draft"
    PUBLIC = "public"
    INTERNAL = "internal"


class EmploymentTerms(str, Enum):
    FULL_TIME = "full-time"
    PART_TIME = "part-time"
    INTERNSHIP = "internship"
    CONTRACTOR = "contractor"
    EMPLOYEE = "employee"
    FREELANCE = "freelance"
    TEMP = "temp"
    SEASONAL = "seasonal"
    VOLUNTEER = "volunteer"
    OTHER = "other"


class BranchTypedDict(TypedDict):
    r"""Details of the branch for which the job is created."""

    id: NotRequired[str]
    r"""A unique identifier for an object."""
    name: NotRequired[str]
    r"""Name of the branch."""


class Branch(BaseModel):
    r"""Details of the branch for which the job is created."""

    id: Optional[str] = None
    r"""A unique identifier for an object."""

    name: Optional[str] = None
    r"""Name of the branch."""


class BlocksTypedDict(TypedDict):
    title: NotRequired[str]
    content: NotRequired[str]


class Blocks(BaseModel):
    title: Optional[str] = None

    content: Optional[str] = None


class SalaryTypedDict(TypedDict):
    min: NotRequired[int]
    r"""Minimum salary payable for the job role."""
    max: NotRequired[int]
    r"""Maximum salary payable for the job role."""
    currency: NotRequired[Nullable[Currency]]
    r"""Indicates the associated currency for an amount of money. Values correspond to [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217)."""
    interval: NotRequired[Nullable[str]]


class Salary(BaseModel):
    min: Optional[int] = None
    r"""Minimum salary payable for the job role."""

    max: Optional[int] = None
    r"""Maximum salary payable for the job role."""

    currency: OptionalNullable[Currency] = UNSET
    r"""Indicates the associated currency for an amount of money. Values correspond to [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217)."""

    interval: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["min", "max", "currency", "interval"]
        nullable_fields = ["currency", "interval"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class JobType(str, Enum):
    JOB_PORTAL = "job_portal"
    JOB_DESCRIPTION = "job_description"


class JobLinksTypedDict(TypedDict):
    type: NotRequired[JobType]
    url: NotRequired[str]


class JobLinks(BaseModel):
    type: Optional[JobType] = None

    url: Optional[str] = None


class JobTypedDict(TypedDict):
    id: NotRequired[str]
    r"""A unique identifier for an object."""
    slug: NotRequired[Nullable[str]]
    title: NotRequired[Nullable[str]]
    r"""The job title of the person."""
    sequence: NotRequired[int]
    r"""Sequence in relation to other jobs."""
    visibility: NotRequired[Visibility]
    r"""The visibility of the job"""
    status: NotRequired[JobStatus]
    r"""The status of the job."""
    code: NotRequired[str]
    r"""The code of the job."""
    language: NotRequired[Nullable[str]]
    r"""language code according to ISO 639-1. For the United States - EN"""
    employment_terms: NotRequired[Nullable[EmploymentTerms]]
    experience: NotRequired[str]
    r"""Level of experience required for the job role."""
    location: NotRequired[Nullable[str]]
    r"""Specifies the location for the job posting."""
    remote: NotRequired[Nullable[bool]]
    r"""Specifies whether the posting is for a remote job."""
    requisition_id: NotRequired[str]
    r"""A job's Requisition ID (Req ID) allows your organization to identify and track a job based on alphanumeric naming conventions unique to your company's internal processes."""
    department: NotRequired[DepartmentTypedDict]
    branch: NotRequired[BranchTypedDict]
    r"""Details of the branch for which the job is created."""
    recruiters: NotRequired[Nullable[List[str]]]
    r"""The recruiter is generally someone who is tasked to help the hiring manager find and screen qualified applicant"""
    hiring_managers: NotRequired[List[str]]
    followers: NotRequired[Nullable[List[str]]]
    description: NotRequired[Nullable[str]]
    r"""A description of the object."""
    description_html: NotRequired[Nullable[str]]
    r"""The job description in HTML format"""
    blocks: NotRequired[List[BlocksTypedDict]]
    closing: NotRequired[Nullable[str]]
    closing_html: NotRequired[Nullable[str]]
    r"""The closing section of the job description in HTML format"""
    closing_date: NotRequired[Nullable[date]]
    salary: NotRequired[SalaryTypedDict]
    url: NotRequired[Nullable[str]]
    r"""URL of the job description"""
    job_portal_url: NotRequired[Nullable[str]]
    r"""URL of the job portal"""
    record_url: NotRequired[Nullable[str]]
    links: NotRequired[List[JobLinksTypedDict]]
    confidential: NotRequired[bool]
    available_to_employees: NotRequired[bool]
    r"""Specifies whether an employee of the organization can apply for the job."""
    tags: NotRequired[Nullable[List[str]]]
    addresses: NotRequired[List[AddressTypedDict]]
    custom_fields: NotRequired[List[CustomFieldTypedDict]]
    deleted: NotRequired[Nullable[bool]]
    r"""Flag to indicate if the object is deleted."""
    owner_id: NotRequired[Nullable[str]]
    published_at: NotRequired[Nullable[datetime]]
    custom_mappings: NotRequired[Nullable[CustomMappingsTypedDict]]
    r"""When custom mappings are configured on the resource, the result is included here."""
    updated_by: NotRequired[Nullable[str]]
    r"""The user who last updated the object."""
    created_by: NotRequired[Nullable[str]]
    r"""The user who created the object."""
    updated_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was last updated."""
    created_at: NotRequired[Nullable[datetime]]
    r"""The date and time when the object was created."""


class Job(BaseModel):
    id: Optional[str] = None
    r"""A unique identifier for an object."""

    slug: OptionalNullable[str] = UNSET

    title: OptionalNullable[str] = UNSET
    r"""The job title of the person."""

    sequence: Optional[int] = None
    r"""Sequence in relation to other jobs."""

    visibility: Optional[Visibility] = None
    r"""The visibility of the job"""

    status: Optional[JobStatus] = None
    r"""The status of the job."""

    code: Optional[str] = None
    r"""The code of the job."""

    language: OptionalNullable[str] = UNSET
    r"""language code according to ISO 639-1. For the United States - EN"""

    employment_terms: OptionalNullable[EmploymentTerms] = UNSET

    experience: Optional[str] = None
    r"""Level of experience required for the job role."""

    location: OptionalNullable[str] = UNSET
    r"""Specifies the location for the job posting."""

    remote: OptionalNullable[bool] = UNSET
    r"""Specifies whether the posting is for a remote job."""

    requisition_id: Optional[str] = None
    r"""A job's Requisition ID (Req ID) allows your organization to identify and track a job based on alphanumeric naming conventions unique to your company's internal processes."""

    department: Optional[Department] = None

    branch: Optional[Branch] = None
    r"""Details of the branch for which the job is created."""

    recruiters: OptionalNullable[List[str]] = UNSET
    r"""The recruiter is generally someone who is tasked to help the hiring manager find and screen qualified applicant"""

    hiring_managers: Optional[List[str]] = None

    followers: OptionalNullable[List[str]] = UNSET

    description: OptionalNullable[str] = UNSET
    r"""A description of the object."""

    description_html: OptionalNullable[str] = UNSET
    r"""The job description in HTML format"""

    blocks: Optional[List[Blocks]] = None

    closing: OptionalNullable[str] = UNSET

    closing_html: OptionalNullable[str] = UNSET
    r"""The closing section of the job description in HTML format"""

    closing_date: OptionalNullable[date] = UNSET

    salary: Optional[Salary] = None

    url: Annotated[
        OptionalNullable[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = UNSET
    r"""URL of the job description"""

    job_portal_url: Annotated[
        OptionalNullable[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = UNSET
    r"""URL of the job portal"""

    record_url: Annotated[
        OptionalNullable[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = UNSET

    links: Optional[List[JobLinks]] = None

    confidential: Optional[bool] = None

    available_to_employees: Optional[bool] = None
    r"""Specifies whether an employee of the organization can apply for the job."""

    tags: OptionalNullable[List[str]] = UNSET

    addresses: Optional[List[Address]] = None

    custom_fields: Optional[List[CustomField]] = None

    deleted: OptionalNullable[bool] = UNSET
    r"""Flag to indicate if the object is deleted."""

    owner_id: OptionalNullable[str] = UNSET

    published_at: OptionalNullable[datetime] = UNSET

    custom_mappings: OptionalNullable[CustomMappings] = UNSET
    r"""When custom mappings are configured on the resource, the result is included here."""

    updated_by: OptionalNullable[str] = UNSET
    r"""The user who last updated the object."""

    created_by: OptionalNullable[str] = UNSET
    r"""The user who created the object."""

    updated_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was last updated."""

    created_at: OptionalNullable[datetime] = UNSET
    r"""The date and time when the object was created."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "id",
            "slug",
            "title",
            "sequence",
            "visibility",
            "status",
            "code",
            "language",
            "employment_terms",
            "experience",
            "location",
            "remote",
            "requisition_id",
            "department",
            "branch",
            "recruiters",
            "hiring_managers",
            "followers",
            "description",
            "description_html",
            "blocks",
            "closing",
            "closing_html",
            "closing_date",
            "salary",
            "url",
            "job_portal_url",
            "record_url",
            "links",
            "confidential",
            "available_to_employees",
            "tags",
            "addresses",
            "custom_fields",
            "deleted",
            "owner_id",
            "published_at",
            "custom_mappings",
            "updated_by",
            "created_by",
            "updated_at",
            "created_at",
        ]
        nullable_fields = [
            "slug",
            "title",
            "language",
            "employment_terms",
            "location",
            "remote",
            "recruiters",
            "followers",
            "description",
            "description_html",
            "closing",
            "closing_html",
            "closing_date",
            "url",
            "job_portal_url",
            "record_url",
            "tags",
            "deleted",
            "owner_id",
            "published_at",
            "custom_mappings",
            "updated_by",
            "created_by",
            "updated_at",
            "created_at",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .consumermetadata import ConsumerMetadata, ConsumerMetadataTypedDict
from .links import Links, LinksTypedDict
from .meta import Meta, MetaTypedDict
from .requestcountallocation import (
    RequestCountAllocation,
    RequestCountAllocationTypedDict,
)
from apideck_unify.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DataTypedDict(TypedDict):
    consumer_id: NotRequired[str]
    application_id: NotRequired[str]
    metadata: NotRequired[ConsumerMetadataTypedDict]
    r"""The metadata of the consumer. This is used to display the consumer in the sidebar. This is optional, but recommended."""
    aggregated_request_count: NotRequired[float]
    request_counts: NotRequired[RequestCountAllocationTypedDict]
    created: NotRequired[str]
    modified: NotRequired[str]
    request_count_updated: NotRequired[str]
    services: NotRequired[List[str]]


class Data(BaseModel):
    consumer_id: Optional[str] = None

    application_id: Optional[str] = None

    metadata: Optional[ConsumerMetadata] = None
    r"""The metadata of the consumer. This is used to display the consumer in the sidebar. This is optional, but recommended."""

    aggregated_request_count: Optional[float] = None

    request_counts: Optional[RequestCountAllocation] = None

    created: Optional[str] = None

    modified: Optional[str] = None

    request_count_updated: Optional[str] = None

    services: Optional[List[str]] = None


class GetConsumersResponseTypedDict(TypedDict):
    r"""Consumers"""

    status_code: int
    r"""HTTP Response Status Code"""
    status: str
    r"""HTTP Response Status"""
    data: List[DataTypedDict]
    meta: NotRequired[MetaTypedDict]
    r"""Response metadata"""
    links: NotRequired[LinksTypedDict]
    r"""Links to navigate to previous or next pages through the API"""


class GetConsumersResponse(BaseModel):
    r"""Consumers"""

    status_code: int
    r"""HTTP Response Status Code"""

    status: str
    r"""HTTP Response Status"""

    data: List[Data]

    meta: Optional[Meta] = None
    r"""Response metadata"""

    links: Optional[Links] = None
    r"""Links to navigate to previous or next pages through the API"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from apideck_unify.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CreateCallbackStateResponseDataTypedDict(TypedDict):
    state: NotRequired[str]
    r"""Callback state"""


class CreateCallbackStateResponseData(BaseModel):
    state: Optional[str] = None
    r"""Callback state"""


class CreateCallbackStateResponseTypedDict(TypedDict):
    r"""Callback state created"""

    status_code: int
    r"""HTTP Response Status Code"""
    status: str
    r"""HTTP Response Status"""
    data: CreateCallbackStateResponseDataTypedDict


class CreateCallbackStateResponse(BaseModel):
    r"""Callback state created"""

    status_code: int
    r"""HTTP Response Status Code"""

    status: str
    r"""HTTP Response Status"""

    data: CreateCallbackStateResponseData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class IntegrationState(str, Enum):
    r"""The current state of the Integration."""

    DISABLED = "disabled"
    NEEDS_CONFIGURATION = "needs_configuration"
    CONFIGURED = "configured"
